==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/arraycheck/ArrayBoundsChecker.h <==
// public class soot.jimple.toolkits.annotation.arraycheck.ArrayBoundsChecker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 52aa5421a5e909b2 soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_ArrayRef$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedSparseGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method$hasArrayLocals$fecefe2e35648963(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_Body$object *);
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method$interpretGraph$045eda43ea97a5f1(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedSparseGraph$object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method_info$hasArrayLocals$fecefe2e35648963;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method_info$interpretGraph$045eda43ea97a5f1;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method$v$6cb273f617b5a17d(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vmethods {
	jboolean	(*hasArrayLocals$fecefe2e35648963)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_Body$object *);
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	jint	(*interpretGraph$045eda43ea97a5f1)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedSparseGraph$object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vmethods	soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_refs	soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_nonrefs {
	jboolean	takeClassField;
	jboolean	takeFieldRef;
	jboolean	takeArrayRef;
	jboolean	takeCSE;
	jboolean	takeRectArray;
	jboolean	addColorTags;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/arraycheck/ArrayBoundsChecker.h <==
// public class soot.jimple.toolkits.annotation.arraycheck.ArrayBoundsChecker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 52aa5421a5e909b2 soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_jimple_ArrayRef$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedSparseGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method$hasArrayLocals$fecefe2e35648963(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method$interpretGraph$045eda43ea97a5f1(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedSparseGraph$object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method_info$hasArrayLocals$fecefe2e35648963;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method_info$interpretGraph$045eda43ea97a5f1;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$method$v$6cb273f617b5a17d(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vmethods {
	jboolean	(*hasArrayLocals$fecefe2e35648963)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jint	(*interpretGraph$045eda43ea97a5f1)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_WeightedDirectedSparseGraph$object *, struct _jc_object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_IntContainer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vmethods	soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_refs	soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_nonrefs {
	jboolean	takeClassField;
	jboolean	takeFieldRef;
	jboolean	takeArrayRef;
	jboolean	takeCSE;
	jboolean	takeRectArray;
	jboolean	addColorTags;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_ArrayBoundsChecker_H_ */
